@@ -3,5 +3,5 @@
 rm ProjectTemplate_*.tar.gz
 rm -rf ProjectTemplate.Rcheck
 R CMD BUILD .
-R CMD CHECK ProjectTemplate_0.1-1.tar.gz
-R CMD INSTALL ProjectTemplate_0.1-1.tar.gz
+R CMD CHECK ProjectTemplate_*.tar.gz
+R CMD INSTALL ProjectTemplate_*.tar.gz
